summary refs log tree commit diff
path: root/pkgs/games/zoom/default.nix
diff options
context:
space:
mode:
Diffstat (limited to 'pkgs/games/zoom/default.nix')
-rw-r--r--pkgs/games/zoom/default.nix15
1 files changed, 10 insertions, 5 deletions
diff --git a/pkgs/games/zoom/default.nix b/pkgs/games/zoom/default.nix
index 200b9c24c7d..d6e79289525 100644
--- a/pkgs/games/zoom/default.nix
+++ b/pkgs/games/zoom/default.nix
@@ -2,21 +2,26 @@
 
 # !!! assert freetype == xorg.freetype
 
-stdenv.mkDerivation {
+stdenv.mkDerivation rec {
   name = "zoom-1.1.5";
   
   src = fetchurl {
-    url = http://www.logicalshift.co.uk/unix/zoom/zoom-1.1.5.tar.gz;
+    url = "http://www.logicalshift.co.uk/unix/zoom/${name}.tar.gz";
     sha256 = "1g6van7f7sg3zfcz80mncnnbccyg2hnm0hq4x558vpsm0lf7z5pj";
   };
   
   buildInputs = [ perl expat xlibsWrapper freetype ];
   
-  # Zoom doesn't add the right directory in the include path.
-  CFLAGS = [ "-I" (freetype + "/include/freetype2") ];
+  NIX_CFLAGS_COMPILE = [
+    # Zoom doesn't add the right directory in the include path.
+    "-I" (freetype + "/include/freetype2")
+
+    # for gcc5; c11 inline semantics breaks the build
+    "-fgnu89-inline"
+  ];
 
   meta = with stdenv.lib; {
-    description = "Player for Z-Code, TADS and HUGO stories or games, usually text adventures ('interactive fiction')";
+    description = "Player for Z-Code, TADS and HUGO stories or games";
     longDescription = ''
       Zoom is a player for Z-Code, TADS and HUGO stories or games. These are
       usually text adventures ('interactive fiction'), and were first created